==> devextreme-23.1.9.tgz: package/bundles/__internal/grids/tree_list/m_master_detail.js <==
/**
 * DevExtreme (bundles/__internal/grids/tree_list/m_master_detail.js)
 * Version: 23.1.9
 * Build date: Mon Mar 11 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
var _extend = require("../../../core/utils/extend");
var _m_master_detail = require("../../grids/grid_core/master_detail/m_master_detail");
var _m_core = _interopRequireDefault(require("./m_core"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var data = function(Base) {
    return function(_dataMasterDetailExte) {
        _inheritsLoose(DataMasterDetailTreeListExtender, _dataMasterDetailExte);

        function DataMasterDetailTreeListExtender() {
            return _dataMasterDetailExte.apply(this, arguments) || this
        }
        var _proto = DataMasterDetailTreeListExtender.prototype;
        _proto.isRowExpanded = function() {
            return this.isRowExpandedHack.apply(this, arguments)
        };
        _proto._processItems = function() {
            return this._processItemsHack.apply(this, arguments)
        };
        _proto._processDataItem = function() {
            return this._processDataItemHack.apply(this, arguments)
        };
        return DataMasterDetailTreeListExtender
    }((0, _m_master_detail.dataMasterDetailExtenderMixin)(Base))
};
_m_core.default.registerModule("masterDetail", (0, _extend.extend)(true, {}, _m_master_detail.masterDetailModule, {
    extenders: {
        controllers: {
            data: data
        }
    }
}));

==> devextreme-23.2.5.tgz: package/bundles/__internal/grids/tree_list/m_master_detail.js <==
/**
 * DevExtreme (bundles/__internal/grids/tree_list/m_master_detail.js)
 * Version: 23.2.5
 * Build date: Mon Mar 11 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
var _extend = require("../../../core/utils/extend");
var _m_master_detail = require("../../grids/grid_core/master_detail/m_master_detail");
var _m_core = _interopRequireDefault(require("./m_core"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
const data = Base => function(_dataMasterDetailExte) {
    _inheritsLoose(DataMasterDetailTreeListExtender, _dataMasterDetailExte);

    function DataMasterDetailTreeListExtender() {
        return _dataMasterDetailExte.apply(this, arguments) || this
    }
    var _proto = DataMasterDetailTreeListExtender.prototype;
    _proto.isRowExpanded = function() {
        return this.isRowExpandedHack.apply(this, arguments)
    };
    _proto._processItems = function() {
        return this._processItemsHack.apply(this, arguments)
    };
    _proto._processDataItem = function() {
        return this._processDataItemHack.apply(this, arguments)
    };
    return DataMasterDetailTreeListExtender
}((0, _m_master_detail.dataMasterDetailExtenderMixin)(Base));
_m_core.default.registerModule("masterDetail", (0, _extend.extend)(true, {}, _m_master_detail.masterDetailModule, {
    extenders: {
        controllers: {
            data: data
        }
    }
}));
